logLik.flexrsurv: Log-Likelihood and the number of observations for a flexrsuv fit.
Description
Function to extract Log-Likelihood and the number of observations from a flexrsuv or flexrsuvclt fit.
Usage
# S3 method for flexrsurv
logLik(object, ...)# S3 method for flexrsurv
nobs(object, ...)
Value
logLik returns a standard logLik object (see logLik)
nobs returns a single number, normally an integer.
Arguments
- object
any object of class flexrsuv results of a flexrsurv fit.
- ...
not used