Print number of observations, number of events, the formula, the estimated coeficients and the log likelihood.
# S3 method for flexrsurv
print(x,
digits = max(3, getOption("digits") - 3), ...)
the result of a call to the flexrsuv function.
the minimum number of significant digits to be printed in values, see print.default.
other options
The default method print.default, and help for the
function flexrsurv, flexrsurvclt.